==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/Util__243.h <==
// final class org.dellroad.jc.cgen.Util$3

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 15b5f0cadcc8e58c org_dellroad_jc_cgen_Util__243

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_Util__243_H_
#define _JC_org_dellroad_jc_cgen_Util__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_Util__243$sub_refs	_jc_org_dellroad_jc_cgen_Util__243$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs	_jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$refs	_jc_org_dellroad_jc_cgen_Util__243$refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$nonrefs	_jc_org_dellroad_jc_cgen_Util__243$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$object	_jc_org_dellroad_jc_cgen_Util__243$object;

typedef const struct _jc_org_dellroad_jc_cgen_Util__243$vmethods	_jc_org_dellroad_jc_cgen_Util__243$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_Util__243$vtable	_jc_org_dellroad_jc_cgen_Util__243$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_Util__243$vtype	_jc_org_dellroad_jc_cgen_Util__243$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_Util__243$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__243$object *);

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_Util__243$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__243$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_Util__243$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_Util__243$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__243$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_Util__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_Util__243$vmethods	org_dellroad_jc_cgen_Util__243;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_Util__243$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_Util__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__243$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__243$refs {
    _jc_org_dellroad_jc_cgen_Util__243$sub_refs	org_dellroad_jc_cgen_Util__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs	org_dellroad_jc_cgen_Util__243;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_Util__243$object {
	_jc_org_dellroad_jc_cgen_Util__243$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_Util__243$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_Util__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_Util__243$vtype _jc_org_dellroad_jc_cgen_Util__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_Util__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_Util__243$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_Util__243_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/Util__243.h <==
// final class org.dellroad.jc.cgen.Util$3

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 15b5f0cadcc8e58c org_dellroad_jc_cgen_Util__243

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_cgen_Util__243_H_
#define _JC_org_dellroad_jc_cgen_Util__243_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_Util__243$sub_refs	_jc_org_dellroad_jc_cgen_Util__243$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs	_jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$refs	_jc_org_dellroad_jc_cgen_Util__243$refs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$nonrefs	_jc_org_dellroad_jc_cgen_Util__243$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_Util__243$object	_jc_org_dellroad_jc_cgen_Util__243$object;

typedef const struct _jc_org_dellroad_jc_cgen_Util__243$vmethods	_jc_org_dellroad_jc_cgen_Util__243$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_Util__243$vtable	_jc_org_dellroad_jc_cgen_Util__243$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_Util__243$vtype	_jc_org_dellroad_jc_cgen_Util__243$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_Util__243$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__243$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_dellroad_jc_cgen_Util__243$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__243$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_Util__243$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_Util__243$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_org_dellroad_jc_cgen_Util__243$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_Util__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_cgen_Util__243$vmethods	org_dellroad_jc_cgen_Util__243;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_Util__243$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_Util__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__243$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__243$refs {
    _jc_org_dellroad_jc_cgen_Util__243$sub_refs	org_dellroad_jc_cgen_Util__243;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_Util__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_cgen_Util__243$sub_nonrefs	org_dellroad_jc_cgen_Util__243;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_Util__243$object {
	_jc_org_dellroad_jc_cgen_Util__243$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_Util__243$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_Util__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_Util__243$vtype _jc_org_dellroad_jc_cgen_Util__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_Util__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_Util__243$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_Util__243_H_ */
